@@ -27,6 +27,7 @@ __all__ = ['StreamEvent',
 @dataclass
 class StreamEvent:
     msg_internal_id: bytes
+    queue: str
     payload: EventPayload
     track_ids: Dict[str, str]
     auth_info: Dict[str, Any]
@@ -76,6 +77,7 @@ class StreamManager(ABC):
 
     async def write_stream(self, *,
                            stream_name: str,
+                           queue: str,
                            payload: EventPayload,
                            track_ids: Dict[str, str],
                            auth_info: Dict[str, Any],
@@ -197,6 +199,6 @@ class NoStreamManager(StreamManager):
             "\n i.e. to use Redis Streams: "
             "\n 1) Install `hopeit.engine` with redis-streams plugin: `pip install hopeit.engine[redis-streams]`"
             "\n 2) Add the following entry to server config json file under `streams` section:"
-            "`stream_manager=hopeit.streams.redis.RedisStreamManager`"
+            '"stream_manager": "hopeit.redis_streams.RedisStreamManager", '
             "\nCheck Plugins/ -> Streams docs section for available additional options."
         )
